@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
-import os
-import urlparse
+from restkit.ext.wsgi_proxy import HostProxy
 from utils import Request, Response
-from lxml.html import tostring
+from paste.fileapp import FileApp
+from webob.dec import wsgify
 from pyquery import PyQuery
 from salade import Salade
-from paste.fileapp import FileApp
+import urlparse
+import os
 
 
 class Saladier(object):
@@ -43,22 +44,23 @@ class Saladier(object):
 
     def get(self, url):
         """get an html page from the app or an url"""
+        req = Request.blank(url)
         if url.startswith('/'):
-            req = Request.blank(url)
-            resp = req.get_response(self.application)
+            app = self.application
         else:
-            resp = Response()
+            app = HostProxy(req.host_url, allowed_methods=['GET'])
+        resp = req.get_response(app)
         if resp.content_type.startswith('text/html') and resp.status.startswith('200'):
             return resp
-        return None
+        return Response()
 
-    def __call__(self, environ, start_response):
-        req = Request(environ)
+    @wsgify(RequestClass=Request)
+    def __call__(self, req):
         if req.path_info.startswith('/_salade/'):
             sub_path = req.path_info[9:]
             filename = os.path.join(self.theme_dir, sub_path)
             if os.path.isfile(filename):
-                return FileApp(filename)(environ, start_response)
+                return FileApp(filename)
 
         if self.root_url:
             scheme, host = urlparse.urlparse(self.root_url)[0:2]
@@ -111,7 +113,7 @@ class Saladier(object):
                 resp.body = body
             else:
                 resp.doc = body
-        return resp(environ, start_response)
+        return resp
 
 
 def make_salade(app, global_config, **local_config):
